/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is the Mozilla SVG project.
 *
 * The Initial Developer of the Original Code is Crocodile Clips Ltd.
 * Portions created by Crocodile Clips are 
 * Copyright (C) 2001 Crocodile Clips Ltd. All
 * Rights Reserved.
 *
 * Contributor(s): 
 *
 *    Alex Fritze <alex.fritze@crocodile-clips.com> (original author)
 *
 */

@namespace url(http://www.w3.org/2000/svg);

a {
  -moz-binding:url('chrome://svg/content/svgBindings.xml#a'); 
}

a * {
  cursor: pointer;
}
               
svg {
  /* XXX see bugs #71191 and #172574 before applying xbl binding to
     either 'svg' or 'svg:not(:root)'
  */

  /* give svg elements block display style, so that they reflow
     correctly when given a relative width/height: */
  display: block;

  font-family: sans-serif;
}
  
